@@ -96,6 +96,16 @@ MemPager(KEYDATA_PAGER_SIZE)
 	load(path);
 }
 
+Keydata::Keydata(Define *pairs, const char *path) :
+MemPager(KEYDATA_PAGER_SIZE)
+{
+	link = 0;
+	memset(&keys, 0, sizeof(keys));
+	load(pairs);
+	if(path)
+		load(path);
+}
+
 Keydata::~Keydata()
 {
 	unlink();
