@@ -108,7 +108,7 @@ int gettimeofday(struct timeval *tv_, void *tz_)
 	struct _timeb tb;
 	_ftime(&tb);
 #endif
-	tv_->tv_sec = tb.time;
+	tv_->tv_sec = (long)tb.time;
 	tv_->tv_usec = tb.millitm * 1000;
 	return 0;
 }	
